# Youtube_comment_word_frequency

# PyPI Overview: The purpose of this PyPI is to analyze the frequency of words in Youtube comments to help improve the content of videos.
# Recently, youtube has become a mainstream video-sharing website, and there are many people who profit from video postings and advertisements from companies. In such a situation, words of both approval and disapproval gather in the comments section of videos, and it is difficult to check all the comments on popular videos. This package enables you to extract word frequency and analyze the opinions and impressions of many people at a glance based on the number of words.

How it works:
Install the library
pip install google-api-python-client


